==> iobroker.speedport-0.0.1.tgz: package/README.md <==
![Logo](admin/speedport.png)
# ioBroker.speedport

[![NPM version](https://img.shields.io/npm/v/iobroker.speedport.svg)](https://www.npmjs.com/package/iobroker.speedport)
[![Downloads](https://img.shields.io/npm/dm/iobroker.speedport.svg)](https://www.npmjs.com/package/iobroker.speedport)
![Number of Installations (latest)](https://iobroker.live/badges/speedport-installed.svg)
![Number of Installations (stable)](https://iobroker.live/badges/speedport-stable.svg)
[![Dependency Status](https://img.shields.io/david/hacki11/iobroker.speedport.svg)](https://david-dm.org/hacki11/iobroker.speedport)

[![NPM](https://nodei.co/npm/iobroker.speedport.png?downloads=true)](https://nodei.co/npm/iobroker.speedport/)

**Tests:** ![Test and Release](https://github.com/hacki11/ioBroker.speedport/workflows/Test%20and%20Release/badge.svg)

## speedport adapter for ioBroker

Fetches data from Telekom Speedport Router

# Supported devices
* Speedport W 925V


## Changelog

### 0.0.1
* (hacki11) initial release

## License
MIT License

Copyright (c) 2021 hacki11 <jur.schmid@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> iobroker.speedport-0.0.2.tgz: package/README.md <==
![Logo](admin/speedport.png)
# ioBroker.speedport

[![NPM version](https://img.shields.io/npm/v/iobroker.speedport.svg)](https://www.npmjs.com/package/iobroker.speedport)
[![Downloads](https://img.shields.io/npm/dm/iobroker.speedport.svg)](https://www.npmjs.com/package/iobroker.speedport)
![Number of Installations (latest)](https://iobroker.live/badges/speedport-installed.svg)
![Number of Installations (stable)](https://iobroker.live/badges/speedport-stable.svg)
[![Dependency Status](https://img.shields.io/david/hacki11/iobroker.speedport.svg)](https://david-dm.org/hacki11/iobroker.speedport)

[![NPM](https://nodei.co/npm/iobroker.speedport.png?downloads=true)](https://nodei.co/npm/iobroker.speedport/)

![Test and Release](https://github.com/hacki11/ioBroker.speedport/workflows/Test%20and%20Release/badge.svg)

## Telekom Speedport adapter for ioBroker

Fetches data from Telekom Speedport Router

## Supported devices
* Speedport W 925V

## Changelog

### 0.0.2
* (hacki11) initial release

## License
MIT License

Copyright (c) 2021 hacki11 <jur.schmid@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
